﻿using UnityEngine;
using UnityEngine.UI;
using System.Collections;

public class UIController : MonoBehaviour {

	public GameObject bubbleObj;
	public Text bubbleText;
	public Slider progressSlider;
	public Text finalCredits;

	private GameObject mainCharacter;
	private Camera mainCamera;

	private float pauseStart = 0;
	private float pauseDelay;
	private string nextMessageNum;

	private float progressStart = 0;
	private float progressDuration = 2;

	public GameObject exitButton;

	// Use this for initialization
	void Start () {
		bubbleObj.SetActive (false);
		progressSlider.gameObject.SetActive (false);
		finalCredits.enabled = false;
		exitButton.SetActive (false);
		mainCharacter = GameObject.Find ("MainCharacter");
		mainCamera = GameObject.Find("MainCamera").GetComponent<Camera>();
	}

	public void ShowCredits () {
		finalCredits.enabled = true;
		exitButton.SetActive (true);
	}
	

	public void ShowMessage (string messageText, float delay){
		bubbleObj.SetActive (true);
		bubbleText.text = messageText;
		pauseDelay = delay;
		pauseStart = Time.time;
	}
	
	public void StartProgess () {
		progressSlider.gameObject.SetActive (true);
		progressStart = Time.time;
		progressSlider.value = 0;
	}

	public void StopProgress () {
		progressSlider.gameObject.SetActive (false);
		progressStart = 0;
		progressSlider.value = 0;
	}

	public void GameExit () {
		Application.Quit ();
	}

	void Update () {
		bubbleObj.transform.position = mainCamera.WorldToScreenPoint(mainCharacter.transform.position + new Vector3 (0, + 1, 0));
		progressSlider.transform.position = mainCamera.WorldToScreenPoint (mainCharacter.transform.position + new Vector3 (0, - 1, 0));

		if (pauseStart > 0)
			if (Time.time > (pauseStart + pauseDelay))
			{
				pauseStart = 0;
				bubbleObj.SetActive (false);
			}

		if (progressStart > 0)
			if (Time.time < (progressStart + progressDuration))
				progressSlider.value = Mathf.Lerp (0, 1, (Time.time - progressStart) / progressDuration);
			else
				StopProgress ();

		if (Input.GetKeyDown (KeyCode.Escape))
			GameExit ();
	}
}
